pub enum GmmError {
InvalidValue(String),
LinalgError(LinalgError),
EmptyCluster(String),
LowerBoundError(String),
NotConverged(String),
KMeansError(KMeansError),
LinfaError(Error),
MinMaxError(MinMaxError),
}Expand description
An error when modeling a GMM algorithm
Variants
InvalidValue(String)
When any of the hyperparameters are set the wrong value
LinalgError(LinalgError)
Errors encountered during linear algebra operations
EmptyCluster(String)
When a cluster has no more data point while fitting GMM
LowerBoundError(String)
When lower bound computation fails
NotConverged(String)
When fitting EM algorithm does not converge
KMeansError(KMeansError)
When initial KMeans fails
LinfaError(Error)
MinMaxError(MinMaxError)