pub enum GmmInitMethod {
KMeans,
Random,
}Expand description
A specifier for the method used for the initialization of the fitting algorithm of GMM
Variants
KMeans
GMM fitting algorithm is initalized with the result of the KMeans clustering.
Random
GMM fitting algorithm is initialized randomly.