pub enum IncrKMeansError<M: Debug> {
InvalidParams(KMeansParamsError),
NotConverged(M),
LinfaError(Error),
}Variants
InvalidParams(KMeansParamsError)
When any of the hyperparameters are set the wrong value
NotConverged(M)
When the distance between the old and new centroids exceeds the tolerance parameter. Not an actual error, just there to signal that the algorithm should keep running.
LinfaError(Error)