pub struct OpticsAnalysis<F: Float> { /* private fields */ }Expand description
The analysis from running OPTICS on a dataset, this allows you iterate over the data points and access their core and reachability distances. The ordering of the points also doesn’t match that of the dataset instead ordering based on the clustering structure worked out during analysis.
Implementations