pub struct OpticsParams<F, D, N>(/* private fields */);Implementations
Sourceimpl<F: Float, D, N> OpticsParams<F, D, N>
impl<F: Float, D, N> OpticsParams<F, D, N>
pub fn new(min_points: usize, dist_fn: D, nn_algo: N) -> Self
Sourcepub fn tolerance(self, tolerance: F) -> Self
pub fn tolerance(self, tolerance: F) -> Self
Distance between points for them to be considered neighbors. Compared to DBSCAN this parameter isn’t strictly necessary but improves execution time by not considering every point. If the tolerance is too low the distances calculated are undefined and no clusters will be returned.